#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = "Gregorio Ambrosio"
__contact__ = "gambrosio[at]uma.es"
__copyright__ = "Copyright 2020, Gregorio Ambrosio"
__date__ = "2020/10/12"
__license__ = "MIT"

# import robotathome.dataset

from robotathome.dataset import Dataset
import cv2

rhds = Dataset("MyRobot@Home")
# rhds = Dataset("MyRobot@Home", path="..")

# rhds = Dataset("MyRobot@Home", path="..", autoload=False)
# rhds.unit["chelmnts"].load_data()
# rhds.unit["2dgeomap"].load_data()
# rhds.unit["hometopo"].load_data()
# rhds.unit["raw"].load_data()
# rhds.unit["lsrscan"].load_data()
# rhds.unit["rgbd"].load_data()
# rhds.unit["lblrgbd"].load_data()

# print(rhds.unit["chelmnts"])
# print(rhds.unit["2dgeomap"])
# print(rhds.unit["hometopo"])
# print(rhds.unit["raw"])
# print(rhds.unit["lsrscan"])
# print(rhds.unit["rgbd"])
# print(rhds.unit["lblrgbd"])

# rhds.unit["chelmnts"].check_folder_size(True)
# rhds.unit["2dgeomap"].check_folder_size(True)
# rhds.unit["hometopo"].check_folder_size(True)
# rhds.unit["raw"].check_folder_size(True)
# rhds.unit["lsrscan"].check_folder_size(True)
# rhds.unit["rgbd"].check_folder_size(True)
# rhds.unit["lblrgbd"].check_folder_size(True)

print(rhds)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Setup for RobotAtHome API
"""

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="robotathome",
    version="0.2.4",
    author="G. Ambrosio-Cestero",
    author_email="gambrosio@uma.es",
    description="'This package provides Python API that assists in loading, parsing, and visualizing the annotations in Robot@Home Dataset",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/goyoambrosio/RobotAtHome_API",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "humanize >= 3.0.0",
        "opencv >= 4.3.0",
        "numpy >= 1.19.1",
        "click >= 7.1.2",
        "urllib3 >= 1.25.10",
        "progressbar >= 2.5"
    ],
    python_requires='>=3.9',
)
